ManatalCandidateList class
Paginated list of candidates from the Manatal Open API.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ManatalCandidateList
Constructors
-
ManatalCandidateList({Key? key, required ManatalClient client, ManatalItemBuilder? itemBuilder, int pageSize = 20, Map<
String, String> ? filters, ManatalPaginationMode mode = ManatalPaginationMode.pages, EdgeInsetsGeometry? padding, Widget emptyBuilder(BuildContext context)?, Widget errorBuilder(BuildContext context, Object error)?, Widget loadingBuilder(BuildContext context)?, Widget paginationBuilder(BuildContext context, int page, int totalPages, int count, VoidCallback? onPrevious, VoidCallback? onNext)?, bool shrinkWrap = false, ScrollPhysics? physics}) -
Creates a candidate list backed by
client.const
Properties
- client → ManatalClient
-
Manatal client used to load candidate pages.
final
- emptyBuilder → Widget Function(BuildContext context)?
-
Widget shown when the list has no results.
final
- errorBuilder → Widget Function(BuildContext context, Object error)?
-
Widget shown when loading a page fails.
final
-
filters
→ Map<
String, String> ? -
Optional query parameters sent to the candidates list endpoint.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → ManatalItemBuilder?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loadingBuilder → Widget Function(BuildContext context)?
-
final
- mode → ManatalPaginationMode
-
final
- padding → EdgeInsetsGeometry?
-
final
- pageSize → int
-
final
- paginationBuilder → Widget Function(BuildContext context, int page, int totalPages, int count, VoidCallback? onPrevious, VoidCallback? onNext)?
-
final
- physics → ScrollPhysics?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shrinkWrap → bool
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited