ManatalPaginatedList class
Paginated list widget backed by the Manatal Open API.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ManatalPaginatedList
Constructors
-
ManatalPaginatedList({Key? key, required ManatalClient client, required ManatalPageLoader loadPage, required ManatalItemBuilder itemBuilder, int pageSize = 20, Map<
String, String> ? filters, ManatalPaginationMode mode = ManatalPaginationMode.pages, EdgeInsetsGeometry? padding, Widget separatorBuilder(BuildContext context, int index)?, Widget emptyBuilder(BuildContext context)?, Widget errorBuilder(BuildContext context, Object error)?, Widget loadingBuilder(BuildContext context)?, Widget paginationBuilder(BuildContext context, int page, int totalPages, int count, VoidCallback? onPrevious, VoidCallback? onNext)?, bool shrinkWrap = false, ScrollPhysics? physics}) -
Creates a generic paginated list using
loadPageanditemBuilder.const
Properties
- client → ManatalClient
-
Manatal client passed to loadPage.
final
- emptyBuilder → Widget Function(BuildContext context)?
-
final
- errorBuilder → Widget Function(BuildContext context, Object error)?
-
final
-
filters
→ Map<
String, String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → ManatalItemBuilder
-
Builds one row for an item on the current page.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loadingBuilder → Widget Function(BuildContext context)?
-
final
- loadPage → ManatalPageLoader
-
Loads one page of API results.
final
- mode → ManatalPaginationMode
-
final
- padding → EdgeInsetsGeometry?
-
final
- pageSize → int
-
final
- paginationBuilder → Widget Function(BuildContext context, int page, int totalPages, int count, VoidCallback? onPrevious, VoidCallback? onNext)?
-
final
- physics → ScrollPhysics?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separatorBuilder → Widget Function(BuildContext context, int index)?
-
final
- shrinkWrap → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ManatalPaginatedList> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited